/**
 * @file compareWithDesignDraft.ts
 */
import type { ReactNode } from 'react';
export interface Options {
    /**
     * The path of design draft.
     */
    designDraft: string;
    /**
     * The component to be compared.
     */
    component: ReactNode;
    /**
     * The threshold of pixel diff between component screenshot and design draft.
     */
    diffThreshold?: number;
    /**
     * The diff result image path between component screenshot and design draft.
     */
    diffResultPath?: string;
    /**
     * A hook called before component screenshot. You can set global styles, load fonts or do some interaction here.
     */
    beforeScreenshot?: () => Promise<unknown> | unknown;
}
export interface CompareResult {
    /**
     * The ssim ( structural similarity index measure ) result between component screenshot and design draft.
     */
    ssim: number;
    /**
     * The data URL of the diff result image.
     */
    diffResultSrc: string;
    /**
     * The number of different pixel between component screenshot and design draft.
     */
    diffPixelCount: number;
}
/**
 * Compare component with design draft.
 * @param designDraft
 * @param component
 * @param diffThreshold
 * @param diffResultPath
 * @param beforeScreenshot
 */
declare const compareWithDesignDraft: ({ designDraft, component, diffThreshold, diffResultPath, beforeScreenshot, }: Options) => Promise<{
    ssim: number;
    diffResultSrc: string;
    diffPixelCount: number;
}>;
export default compareWithDesignDraft;
